.. _apiref:

===============
 API Reference
===============

:Release: |version|
:Date: |today|

Mode
====

.. toctree::
    :maxdepth: 1

    mode
    mode.debug
    mode.exceptions
    mode.locals
    mode.proxy
    mode.services
    mode.signals
    mode.supervisors
    mode.threads
    mode.timers
    mode.worker

Typehints
=========

.. toctree::
    :maxdepth: 1

    mode.types
    mode.types.services
    mode.types.signals
    mode.types.supervisors

Event Loops
===========

.. toctree::
    :maxdepth: 1

    mode.loop
    mode.loop.eventlet
    mode.loop.gevent
    mode.loop.uvloop

Utils
=====

.. toctree::
    :maxdepth: 1

    mode.utils.aiter
    mode.utils.collections
    mode.utils.futures
    mode.utils.graphs
    mode.utils.imports
    mode.utils.locals
    mode.utils.logging
    mode.utils.loops
    mode.utils.mocks
    mode.utils.objects
    mode.utils.queues
    mode.utils.text
    mode.utils.times
    mode.utils.tracebacks
    mode.utils.trees
